#
# k2hftfuse for file transaction by FUSE-based file system
#
# Copyright 2015 Yahoo Japan Corporation.
#
# k2hftfuse is file transaction system on FUSE file system with
# K2HASH and K2HASH TRANSACTION PLUGIN, CHMPX.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Wed Jun 22 2016
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.41

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: file transaction by FUSE-based file system with k2hash.
Name: k2hftfuse
Version: 1.0.41
Release: %{package_revision}%{?dist}
License: MIT
Group: System Environment/Libraries
URL: https://github.com/yahoojapan/k2hftfuse
Source0: https://github.com/yahoojapan/k2hftfuse/archive/%{gittag}/%{name}-%{version}.tar.gz
Requires: libfullock%{?_isa} >= 1.0.55, k2hash%{?_isa} >= 1.0.90, chmpx%{?_isa} >= 1.0.103, k2htpdtor%{?_isa} >= 1.0.43, fuse
BuildRequires: git-core gcc-c++ make libtool libfullock-devel >= 1.0.55, k2hash-devel >= 1.0.90, chmpx-devel >= 1.0.103, k2htpdtor >= 1.0.43, libyaml-devel, fuse, fuse-devel

%description
k2hftfuse is file transaction system on FUSE file system with K2HASH
and K2HASH TRANSACTION PLUGIN, CHMPX.

You can run k2hftfuse by manual and mount/umount system command(or
fusermount command). If you run it manually, you can specify some fol-
lowing options.

For using mount/umount command, you need to modify /etc/fstab and add
following line.

You can start k2hftfuse in any way. And you can see mount information
by df command.

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static 
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'

%if %{make_check}
%check
%{__make} check
%endif

%if %{defined ldconfig_scriptlets}
%ldconfig_scriptlets
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%if 0%{?rhel} == 6
%clean
rm -rf %{buildroot}
%endif

%files
%if 0%{?rhel} == 6
%doc COPYING
%defattr(-,root,root)
%else
%license COPYING
%endif
%doc README AUTHORS ChangeLog
%{_mandir}/man1/*
%{_bindir}/*

#
# devel package
#
%package devel
Summary: file transaction by FUSE-based file system with k2hash. (development)
Requires: %{name}%{?_isa} = %{version}-%{release}, libfullock-devel%{?_isa} >= 1.0.55, k2hash-devel%{?_isa} >= 1.0.90, chmpx-devel%{?_isa} >= 1.0.103, k2htpdtor%{?_isa} >= 1.0.43, libyaml-devel, fuse, fuse-devel

%description devel
Development package for building with k2hftfuse shared library.
This package has header files and symbols for it.

%files devel
%if 0%{?rhel} == 6
%defattr(-,root,root)
%endif
%doc README AUTHORS ChangeLog
%{_includedir}/*

%changelog
* Mon Oct 30 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.41-1
- Changed support OS (fedora and ubuntu) and updated tool - #58

* Tue Oct 03 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.40
- Updated versions of dependent packages - #56

* Thu Aug 31 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.39
- Updated tool scripts and support OSs - #54
- Fixed bugs about test scripts - #53
- Fixed .gitignore to exclude APKBUILD.templ - #52

* Mon Mar 06 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.38
- Updated building/packaging logic for ALPINE - #50

* Sat Feb 11 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.37
- Adjusted the waiting time during test execution - #48
- Changed CI OSs and added Alpine OS - #47
- Updated header and footer in comment lines - #46
- Updated issue/pullrequest templates and README.md - #44
- Added ShellCheck processing and reviewed cppcheck - #43
- Eliminated unnecessary copies in build_helper.sh - #42
- Updated github actions process and support os, and fixed bugs - #41
- Updated scripts for adding grep params and replacing which to command - #40
- Updated common build scripts - #39
- Updated Antpickax common scripts and tools under the buildutils directory - #38
- Fixed errors reported by cppcheck 2.9 - #37
- Enabled external customization of configure.ac and fixed for building - #36
- Fixes markup syntax errors - #35
- Drops Fedora28 and CentOS6.x from our support OS - #34

* Thu Dec 17 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.36
- Fixed centos8 build and removed centos6 build - #32

* Thu Nov 26 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.35
- Switched Travis CI to Github actions and extended supported OS - #30
- Fixed a error by cppcheck - #29

* Tue Dec 24 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.34
- Fixed misspellings in ChangeLog - #27

* Fri Dec 20 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.33
- Fixed bugs and updated version of dependency packages - #25

* Wed Mar 13 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.32
- Fixed codes for cppcheck 1.87 - #22

* Thu Jan 17 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.31
- Fixed misspelling, and etc - #19
- Added check using cppcheck - #18
- Reflected the spelling check result for all sources - #17

* Tue Dec 11 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.30
- Updated common build tool files

* Fri Dec 07 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.29
- Changed to strict packaging and changed documents

* Wed Oct 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.28
- Fixed spec file and updated dependency

* Mon Jul 02 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.27
- avoid static object initialization order problem(SIOF)

* Thu May 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.26
- Cleanup credit comments in sources and Modified etc
- Changed build logic to new for rpm/debian packaging
- Fixed a filename typo of make_variables.sh

* Tue Mar 27 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.25
- Update dependency on k2hash/chmpx/k2htp_dtor and README/AUTHORS

* Wed Feb 28 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.24
- Added/Modified files for new developer package

* Tue Mar 28 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.23
- Supported trimmed contents format keyword
- Added lib_version_for_link option to make_valiables.sh
- Updated submodule dependency for k2htp_dtor/chmpx/k2hash/fullock

* Thu Feb 23 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.22
- Only version increment for packaging

* Fri Feb 17 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.21
- Fixed a bug about FORMAT does not work in k2hftfusesvr

* Wed Feb 15 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.20
- Updated dependency for fixing bugs in libfullock

* Mon Dec 19 2016 Takeshi Nakatani <ggtakec@gmail.com> 1.0.19
- Fixed a bug and Updated submodules and Changed .travis.yaml - #1

* Wed Dec 07 2016 Takeshi Nakatani <ggtakec@gmail.com> 1.0.18
- First version of open sorce on Github
